/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.monitor;

import org.apache.axis.Constants;
import org.apache.axis.MessageContext;
import org.apache.axis.transport.http.AxisServlet;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.juddi.IRegistry;
import org.apache.juddi.datatype.RegistryObject;
import org.apache.juddi.datatype.request.AuthInfo;
import org.apache.juddi.datatype.request.DiscardAuthToken;
import org.apache.juddi.datatype.request.Publish;
import org.w3c.dom.Element;

/**
 * @author Anou Mana (anou_mana@users.sourceforge.net)
 */
public abstract class MonitorAdapter implements Monitor
{
  // private reference to the jUDDI logger
  private static Log log = LogFactory.getLog(MonitorAdapter.class);

  protected MonitorData data = null;

  public MonitorAdapter()
  {
    init();
  }

  protected void init()
  {
    data = new MonitorData();
  }

  public void inspectMessageContext(MessageContext messageContext)
  {
    String remoteHost = messageContext.getProperty(Constants.MC_REMOTE_ADDR).toString();

    String requestedURI = messageContext.getProperty(Constants.MC_RELATIVE_PATH).toString();

    log.debug("RequestedURI: " + requestedURI +",RemoteHost: " + remoteHost);

    data.setRequestURI( requestedURI );
    data.setRemoteHost( remoteHost );

    // inspect the called Servlet value now since to obtain
    // this object is a simple 'getProperty' call from
    // MessageContext.

    AxisServlet axisServlet =
      (AxisServlet)messageContext.getProperty("transport.http.servlet");
  }

  public void inspectUDDIRequest(Element request)
  {
    if(request != null)
    {
      data.setCalledFunction(request.getLocalName());

      String generic = request.getAttribute("generic");
      if (generic == null)
        generic = IRegistry.UDDI_V2_GENERIC;

      data.setUddiVersion(generic);
    }
  }

  public void inspectRegistryObject(RegistryObject registryObject)
  {
    AuthInfo authInfo = null;

    // As of UDDI v3.0 get_authToken and discard_authToken are
    // no longer part of the Publish API (they are part of the
    // new SecurityPolicy API) so the associated request classes
    // do not implement "Publish".

    // Since the DiscardAuthToken doesn't implement Publish we
    // need to check it specifically (we never cared about the
    // GetAuthToken requests here so we now ignore them).

    if (registryObject instanceof Publish)
      authInfo = ((Publish)registryObject).getAuthInfo();
    else if (registryObject instanceof DiscardAuthToken)
      authInfo = ((DiscardAuthToken)registryObject).getAuthInfo();

    if (authInfo != null)
      data.setAuthToken(authInfo.getValue());
  }

  public void addMonitorFault( String faultString )
  {
    String fault = data.getFault();
    if(fault != "")
    {
      faultString = "; " + faultString;
    }

    data.setFault(fault + faultString);
  }

  public abstract void log();
}