/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.monitor;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.juddi.util.Config;
import org.apache.juddi.util.Loader;

/**
 * @author Anou Mana (anou_mana@apache.org)
 */
public class MonitorFactory
{
  // private reference to the jUDDI logger
  private static Log log = LogFactory.getLog(MonitorFactory.class);

  // Monitor property key & default implementation
  private static final String IMPL_KEY = "juddi.monitor";
  private static final String DEFAULT_IMPL = "org.apache.juddi.monitor.jdbc.JDBCMonitor";

  private static Class monitorClass = null;

  /**
   * Returns a new instance of a DefaultMonitor.
   *
   * @return DefaultMonitor
   */
  public static Monitor getMonitor()
  {
    Monitor monitor = null;

    // Determine if monitor is needed. This is done by 
    // looking for the existance of a "juddi.monitor" 
    // property value.  If a value exists and it's not 
    // equal to null then the registry will be monitoring
    // http traffic/requests.
    
    String needsMonitor = Config.getStringProperty(IMPL_KEY,null);
    if (needsMonitor != null)
    {
      getMonitorClass();
  
      if (monitorClass != null)
      {
        try
        {
          // try to instantiate the Monitor
          monitor = (Monitor)monitorClass.newInstance();
        }
        catch(java.lang.Exception ex)
        {
          log.error("Exception while attempting to instantiate subclass " +
                      "of Monitor: " + "\n" + ex.getMessage(),ex);
        }
      }
    }
    
    return monitor;
  }

  private static synchronized void getMonitorClass()
  {
    if (monitorClass == null)
    {
      // Obtain the class name of the Monitor to create
      String className = Config.getStringProperty(IMPL_KEY,DEFAULT_IMPL);

      // Write Monitor property to the log for good measure
      log.debug(className);

      try
      {
        // Instruct class loader to load the Monitor
        monitorClass = Loader.getClassForName(className);
      }
      catch(ClassNotFoundException cnfex)
      {
        log.error("The specified Monitor class '" + className +
          "' was not found in classpath.",cnfex);
      }
    }
  }
}