/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.monitor.jdbc;

import java.sql.Connection;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.juddi.datatype.RegistryObject;
import org.apache.juddi.error.RegistryException;
import org.apache.juddi.monitor.MonitorData;
import org.apache.juddi.util.jdbc.ConnectionManager;

/**
 * @author Anou Mana (anou_mana@users.sourceforge.net)
 */
public class MonitorDAO
{
  // private reference to the jUDDI logger
  private static Log log = LogFactory.getLog(MonitorDAO.class);


  public MonitorDAO()
  {
    super();
  }

  public void init()
  {
  }

  /**
   *
   */
  public RegistryObject insert(RegistryObject regObject)
    throws RegistryException
  {
    Connection connection = null;
    MonitorData data = (MonitorData)regObject;

    try
    {
      // grab a JDBC connection
      connection = ConnectionManager.aquireConnection();
      if(connection != null)
      {
        MonitorTable.insert(data,connection);
        connection.commit();
      }

      return regObject;
    }
    catch(Exception ex)
    {
      // rollback for *any* exception
      try { connection.rollback(); }
      catch(Exception e) { log.error(ex); }

      // write to the log
      log.error(ex);

      // prep RegistryFault to throw
      if (ex instanceof RegistryException)
        throw (RegistryException)ex;
      else
        throw new RegistryException(ex);
    }
    finally
    {
      // close the JDBC connection
      try {
        if (connection != null)
          connection.close();
      }
      catch(Exception ex) { log.error(ex); }
    }
  }

}
